Struct prost_types::compiler::CodeGeneratorRequest
source · pub struct CodeGeneratorRequest {
pub file_to_generate: Vec<String>,
pub parameter: Option<String>,
pub proto_file: Vec<FileDescriptorProto>,
pub compiler_version: Option<Version>,
}Expand description
An encoded CodeGeneratorRequest is written to the plugin’s stdin.
Fields
file_to_generate: Vec<String>The .proto files that were explicitly listed on the command-line. The code generator should generate code only for these files. Each file’s descriptor will be included in proto_file, below.
parameter: Option<String>The generator parameter passed on the command-line.
proto_file: Vec<FileDescriptorProto>FileDescriptorProtos for all files in files_to_generate and everything they import. The files will appear in topological order, so each file appears before any file that imports it.
protoc guarantees that all proto_files will be written after the fields above, even though this is not technically guaranteed by the protobuf wire format. This theoretically could allow a plugin to stream in the FileDescriptorProtos and handle them one by one rather than read the entire set into memory at once. However, as of this writing, this is not similarly optimized on protoc’s end – it will store all fields in memory at once before sending them to the plugin.
Type names of fields and extensions in the FileDescriptorProto are always fully qualified.
compiler_version: Option<Version>The version number of protocol compiler.
Implementations