pub struct CodeGeneratorResponse {
    pub error: Option<String>,
    pub supported_features: Option<u64>,
    pub file: Vec<File>,
}
The plugin writes an encoded CodeGeneratorResponse to stdout.

Fields

error: Option<String>

Error message. If non-empty, code generation failed. The plugin process should exit with status code zero even if it reports an error in this way.

This should be used to indicate errors in .proto files which prevent the code generator from generating correct code. Errors which indicate a problem in protoc itself – such as the input CodeGeneratorRequest being unparseable – should be reported by writing a message to stderr and exiting with a non-zero status code.

supported_features: Option<u64>

A bitmask of supported features that the code generator supports. This is a bitwise “or” of values from the Feature enum.

file: Vec<File>

Implementations

Returns the value of error, or the default value if error is unset.

Returns the value of supported_features, or the default value if supported_features is unset.