[−][src]Enum prost_types::NullValue
NullValue is a singleton enumeration to represent the null value for the
Value type union.
The JSON representation for NullValue is JSON null.
Variants
NullValueNull value.
Methods
impl NullValue[src]
pub fn is_valid(value: i32) -> bool[src]
Returns true if value is a variant of NullValue.
pub fn from_i32(value: i32) -> Option<NullValue>[src]
Converts an i32 to a NullValue, or None if value is not a valid variant.