Enum prost_types::Syntax
source · #[repr(i32)]
pub enum Syntax {
Proto2,
Proto3,
}Expand description
The syntax in which a protocol buffer element is defined.
Variants
Proto2
Syntax proto2.
Proto3
Syntax proto3.
Implementations
sourceimpl Syntax
impl Syntax
sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.