Enum prost_types::field_options::CType
source · #[repr(i32)]
pub enum CType {
String,
Cord,
StringPiece,
}Variants
String
Default mode.
Cord
StringPiece
Implementations
sourceimpl CType
impl CType
sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.