Struct prost_types::EnumDescriptorProto [−][src]
pub struct EnumDescriptorProto {
pub name: Option<String>,
pub value: Vec<EnumValueDescriptorProto>,
pub options: Option<EnumOptions>,
pub reserved_range: Vec<EnumReservedRange>,
pub reserved_name: Vec<String>,
}Expand description
Describes an enum type.
Fields
name: Option<String>value: Vec<EnumValueDescriptorProto>options: Option<EnumOptions>reserved_range: Vec<EnumReservedRange>Range of reserved numeric values. Reserved numeric values may not be used by enum values in the same enum declaration. Reserved ranges may not overlap.
reserved_name: Vec<String>Reserved enum value names, which may not be reused. A given name may only be reserved once.
Implementations