Struct prost_types::EnumOptions [−][src]
pub struct EnumOptions {
pub allow_alias: Option<bool>,
pub deprecated: Option<bool>,
pub uninterpreted_option: Vec<UninterpretedOption>,
}Fields
allow_alias: Option<bool>Set this option to true to allow mapping different tag names to the same value.
deprecated: Option<bool>Is this enum deprecated? Depending on the target platform, this can emit Deprecated annotations for the enum, or it will be completely ignored; in the very least, this is a formalization for deprecating enums.
uninterpreted_option: Vec<UninterpretedOption>The parser stores options it doesn’t recognize here. See above.
Implementations
Returns the value of allow_alias, or the default value if allow_alias is unset.
Returns the value of deprecated, or the default value if deprecated is unset.