Struct prost_types::MethodOptions [−][src]
pub struct MethodOptions {
pub deprecated: Option<bool>,
pub idempotency_level: Option<i32>,
pub uninterpreted_option: Vec<UninterpretedOption>,
}Fields
deprecated: Option<bool>Is this method deprecated? Depending on the target platform, this can emit Deprecated annotations for the method, or it will be completely ignored; in the very least, this is a formalization for deprecating methods.
idempotency_level: Option<i32>uninterpreted_option: Vec<UninterpretedOption>The parser stores options it doesn’t recognize here. See above.
Implementations
Returns the value of deprecated, or the default value if deprecated is unset.
Returns the enum value of idempotency_level, or the default if the field is unset or set to an invalid enum value.
Sets idempotency_level to the provided enum value.