Struct prost_types::UninterpretedOption
source · pub struct UninterpretedOption {
pub name: Vec<NamePart>,
pub identifier_value: Option<String>,
pub positive_int_value: Option<u64>,
pub negative_int_value: Option<i64>,
pub double_value: Option<f64>,
pub string_value: Option<Vec<u8>>,
pub aggregate_value: Option<String>,
}Expand description
A message representing a option the parser does not recognize. This only appears in options protos created by the compiler::Parser class. DescriptorPool resolves these when building Descriptor objects. Therefore, options protos in descriptor objects (e.g. returned by Descriptor::options(), or produced by Descriptor::CopyTo()) will never have UninterpretedOptions in them.
Fields
name: Vec<NamePart>identifier_value: Option<String>The value of the uninterpreted option, in whatever type the tokenizer identified it as during parsing. Exactly one of these should be set.
positive_int_value: Option<u64>negative_int_value: Option<i64>double_value: Option<f64>string_value: Option<Vec<u8>>aggregate_value: Option<String>Implementations
sourceimpl UninterpretedOption
impl UninterpretedOption
sourcepub fn identifier_value(&self) -> &str
pub fn identifier_value(&self) -> &str
Returns the value of identifier_value, or the default value if identifier_value is unset.
sourcepub fn positive_int_value(&self) -> u64
pub fn positive_int_value(&self) -> u64
Returns the value of positive_int_value, or the default value if positive_int_value is unset.
sourcepub fn negative_int_value(&self) -> i64
pub fn negative_int_value(&self) -> i64
Returns the value of negative_int_value, or the default value if negative_int_value is unset.
sourcepub fn double_value(&self) -> f64
pub fn double_value(&self) -> f64
Returns the value of double_value, or the default value if double_value is unset.
sourcepub fn string_value(&self) -> &[u8]ⓘNotable traits for &mut [u8]impl Write for &mut [u8]impl Read for &[u8]
pub fn string_value(&self) -> &[u8]ⓘNotable traits for &mut [u8]impl Write for &mut [u8]impl Read for &[u8]
Returns the value of string_value, or the default value if string_value is unset.
sourcepub fn aggregate_value(&self) -> &str
pub fn aggregate_value(&self) -> &str
Returns the value of aggregate_value, or the default value if aggregate_value is unset.