[][src]Struct prost_types::compiler::CodeGeneratorResponse

pub struct CodeGeneratorResponse {
    pub error: Option<String>,
    pub file: Vec<File>,
}

The plugin writes an encoded CodeGeneratorResponse to stdout.

Fields

error: Option<String>

Error message. If non-empty, code generation failed. The plugin process should exit with status code zero even if it reports an error in this way.

This should be used to indicate errors in .proto files which prevent the code generator from generating correct code. Errors which indicate a problem in protoc itself -- such as the input CodeGeneratorRequest being unparseable -- should be reported by writing a message to stderr and exiting with a non-zero status code.

file: Vec<File>

Methods

impl CodeGeneratorResponse[src]

pub fn error(&self) -> &str[src]