[−][src]Enum prost_types::field::Kind
Basic field types.
Variants
TypeUnknownField type unknown.
TypeDoubleField type double.
TypeFloatField type float.
TypeInt64Field type int64.
TypeUint64Field type uint64.
TypeInt32Field type int32.
TypeFixed64Field type fixed64.
TypeFixed32Field type fixed32.
TypeBoolField type bool.
TypeStringField type string.
TypeGroupField type group. Proto2 syntax only, and deprecated.
TypeMessageField type message.
TypeBytesField type bytes.
TypeUint32Field type uint32.
TypeEnumField type enum.
TypeSfixed32Field type sfixed32.
TypeSfixed64Field type sfixed64.
TypeSint32Field type sint32.
TypeSint64Field type sint64.
Methods
impl Kind[src]
pub fn is_valid(value: i32) -> bool[src]
Returns true if value is a variant of Kind.
pub fn from_i32(value: i32) -> Option<Kind>[src]
Converts an i32 to a Kind, or None if value is not a valid variant.