[−][src]Enum prost_types::method_options::IdempotencyLevel
Is this method side-effect-free (or safe in HTTP parlance), or idempotent, or neither? HTTP based RPC implementation may choose GET verb for safe methods, and PUT verb for idempotent methods instead of the default POST.
Variants
IdempotencyUnknownNoSideEffectsimplies idempotent
Idempotentidempotent, but may have side effects
Methods
impl IdempotencyLevel[src]
pub fn is_valid(value: i32) -> bool[src]
Returns true if value is a variant of IdempotencyLevel.
pub fn from_i32(value: i32) -> Option<IdempotencyLevel>[src]
Converts an i32 to a IdempotencyLevel, or None if value is not a valid variant.