Struct prost_types::UninterpretedOption [−][src]
pub struct UninterpretedOption {
pub name: Vec<NamePart>,
pub identifier_value: Option<String>,
pub positive_int_value: Option<u64>,
pub negative_int_value: Option<i64>,
pub double_value: Option<f64>,
pub string_value: Option<Vec<u8>>,
pub aggregate_value: Option<String>,
}Expand description
A message representing a option the parser does not recognize. This only appears in options protos created by the compiler::Parser class. DescriptorPool resolves these when building Descriptor objects. Therefore, options protos in descriptor objects (e.g. returned by Descriptor::options(), or produced by Descriptor::CopyTo()) will never have UninterpretedOptions in them.
Fields
name: Vec<NamePart>identifier_value: Option<String>The value of the uninterpreted option, in whatever type the tokenizer identified it as during parsing. Exactly one of these should be set.
positive_int_value: Option<u64>negative_int_value: Option<i64>double_value: Option<f64>string_value: Option<Vec<u8>>aggregate_value: Option<String>Implementations
Returns the value of identifier_value, or the default value if identifier_value is unset.
Returns the value of positive_int_value, or the default value if positive_int_value is unset.
Returns the value of negative_int_value, or the default value if negative_int_value is unset.
Returns the value of double_value, or the default value if double_value is unset.
Returns the value of string_value, or the default value if string_value is unset.
Returns the value of aggregate_value, or the default value if aggregate_value is unset.